From 41aa803c9c97222081adf5dc8068d809f4b8be65 Mon Sep 17 00:00:00 2001
From: Richard Yen <richyen3@gmail.com>
Date: Sat, 22 Feb 2020 00:16:38 -0800
Subject: [PATCH 1/2] Create docker files to make development easier

---
 Dockerfile         |  7 +++++++
 docker-compose.yml | 18 ++++++++++++++++++
 entrypoint.sh      |  5 +++++
 3 files changed, 30 insertions(+)
 create mode 100644 Dockerfile
 create mode 100644 docker-compose.yml
 create mode 100755 entrypoint.sh

diff --git a/Dockerfile b/Dockerfile
new file mode 100644
index 0000000..cc2c813
--- /dev/null
+++ b/Dockerfile
@@ -0,0 +1,7 @@
+FROM python:3.7
+ENV PYTHONUNBUFFERED 1
+RUN mkdir /code
+WORKDIR /code
+COPY requirements.txt /code/
+RUN pip install -r requirements.txt
+COPY . /code/
diff --git a/docker-compose.yml b/docker-compose.yml
new file mode 100644
index 0000000..71a0d3c
--- /dev/null
+++ b/docker-compose.yml
@@ -0,0 +1,18 @@
+version: '3'
+
+services:
+  db:
+    image: postgres
+    environment:
+      POSTGRES_PASSWORD: "postgres"
+      POSTGRES_USER: "postgres"
+      POSTGRES_DB: "pgweb"
+  web:
+    build: .
+    entrypoint: /code/entrypoint.sh
+    volumes:
+      - .:/code
+    ports:
+      - "8000:8000"
+    depends_on:
+      - db
diff --git a/entrypoint.sh b/entrypoint.sh
new file mode 100755
index 0000000..db75ffa
--- /dev/null
+++ b/entrypoint.sh
@@ -0,0 +1,5 @@
+#!/bin/bash
+
+python /code/manage.py makemigrations
+python /code/manage.py migrate
+python /code/manage.py runserver 0.0.0.0:8000
-- 
2.20.1

